@@ -65,7 +65,7 @@
 #' @importFrom concaveman concaveman
 #' @importFrom doFuture registerDoFuture
 #' @importFrom doRNG %dorng%
-#' @importFrom foreach %do% %dopar% foreach
+#' @importFrom foreach %do% %dopar% foreach setDoPar
 #' @importFrom future multisession plan
 #' @importFrom grDevices chull
 #' @importFrom iterators icount
@@ -280,8 +280,9 @@ lrren <- function(obs_locs,
 
     ### Set function used in foreach
     if (parallel == TRUE) {
-      doFuture::registerDoFuture()
-      future::plan(multisession, workers = n_core)
+      oldplan <- doFuture::registerDoFuture()
+      on.exit(with(oldplan, foreach::setDoPar(fun=fun, data=data, info=info)), add = TRUE)
+      future::plan(future::multisession, workers = n_core)
       `%fun%` <- doRNG::`%dorng%`
     } else { `%fun%` <- foreach::`%do%` }
 
