@@ -296,24 +296,6 @@ test_that("lrren works", {
           verbose = FALSE)
   )
 
-  # Estimate and cross-validation
-  ## Unbalanced sampling
-  ## Parallel (n = 2 cores)
-  expect_named(
-    lrren(obs_locs = obs_locs,
-          predict = FALSE,
-          predict_locs = NULL,
-          conserve = TRUE,
-          cv = TRUE,
-          kfold = 10,
-          balance = TRUE,
-          parallel = TRUE,
-          n_core = 2,
-          poly_buffer = NULL,
-          obs_window = NULL,
-          verbose = FALSE)
-  )
-
   # Estimate and predict
   expect_named(
     lrren(obs_locs = obs_locs,
@@ -332,3 +314,31 @@ test_that("lrren works", {
 
 }
 )
+
+## WORKAROUND: Avoid R bug 18119 [1] that is trigger when for instance the
+## 'tcltk' package is loaded on macOS, or when running in the RStudio Console
+## [1] https://bugs.r-project.org/bugzilla/show_bug.cgi?id=18119
+if (getRversion() >= "4.0.0" && getRversion() <= "4.1.0") {
+  options(parallelly.makeNodePSOCK.setup_strategy = "sequential")
+}
+
+test_that("parallel processing with future package functions properly", {
+  # Estimate and cross-validation
+  ## Unbalanced sampling
+  ## Parallel (n = 2 cores)
+  expect_named(
+    lrren(obs_locs = obs_locs,
+          predict = FALSE,
+          predict_locs = NULL,
+          conserve = TRUE,
+          cv = TRUE,
+          kfold = 10,
+          balance = TRUE,
+          parallel = TRUE,
+          n_core = 2,
+          poly_buffer = NULL,
+          obs_window = NULL,
+          verbose = FALSE)
+  )
+}
+)
\ No newline at end of file
