@@ -170,8 +170,17 @@ test_that("perlrren works", {
              alpha = 0.01,
              n_sim = 10)
   )
-  
-  # Parallel
+}
+)
+
+## WORKAROUND: Avoid R bug 18119 [1] that is trigger when for instance the
+## 'tcltk' package is loaded on macOS, or when running in the RStudio Console
+## [1] https://bugs.r-project.org/bugzilla/show_bug.cgi?id=18119
+if (getRversion() >= "4.0.0" && getRversion() <= "4.1.0") {
+  options(parallelly.makeNodePSOCK.setup_strategy = "sequential")
+}
+
+test_that("parallel processing with future package functions properly", {
   expect_named(
     perlrren(obs_ppp = obs_locs,
              covariates = ims,
@@ -180,6 +189,5 @@ test_that("perlrren works", {
              n_core = 2,
              n_sim = 10)
   )
-  
 }
-)
+)
\ No newline at end of file
